@@ -1,9 +1,8 @@
-from django.contrib import admin
-
 from django.apps import apps
+from django.contrib import admin
 
 # Register your models here.
 app = apps.get_app_config("gqlauth")
 
-for model_name, model in app.models.items():
+for _, model in app.models.items():
     admin.site.register(model)
