@@ -1,13 +1,14 @@
 from smtplib import SMTPException
 from uuid import UUID
 
+from asgiref.sync import sync_to_async
 from django.contrib.auth import get_user_model
 from django.contrib.auth.forms import PasswordChangeForm, SetPasswordForm
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.signing import BadSignature, SignatureExpired
 from django.db import transaction
-from django.utils.module_loading import import_string
 import strawberry
+from strawberry.types import Info
 from strawberry_django_jwt.exceptions import JSONWebTokenError, JSONWebTokenExpired
 
 from gqlauth.constants import Messages, TokenAction
@@ -30,11 +31,12 @@ from gqlauth.forms import (
     RegisterForm,
     UpdateAccountForm,
 )
-from gqlauth.models import Captcha, UserStatus
+from gqlauth.models import Captcha as CaptchaModel
+from gqlauth.models import UserStatus
 from gqlauth.settings import gqlauth_settings as app_settings
 from gqlauth.shortcuts import get_user_by_email, get_user_to_login
 from gqlauth.signals import user_registered, user_verified
-from gqlauth.types import CaptchaType
+from gqlauth.types_ import CaptchaType
 from gqlauth.utils import (
     g_user,
     get_payload_from_token,
@@ -44,16 +46,27 @@ from gqlauth.utils import (
 )
 
 UserModel = get_user_model()
-if app_settings.EMAIL_ASYNC_TASK and isinstance(app_settings.EMAIL_ASYNC_TASK, str):
-    async_email_func = import_string(app_settings.EMAIL_ASYNC_TASK)
-else:
-    async_email_func = None
 
 
-class Cap:
-    @strawberry.mutation
-    def Field(self) -> CaptchaType:
-        return Captcha.create_captcha()
+class Captcha:
+    """
+    Creates a brand-new captcha.
+    Returns a base64 encoded string of the captcha.
+    And uuid representing the captcha id in the database.
+    When you will try to log in or register You will
+    need submit that uuid With the user input.
+    **The captcha will be invoked when the timeout expires**.
+    """
+
+    @strawberry.mutation(description=__doc__)
+    def field(self) -> CaptchaType:
+
+        return CaptchaModel.create_captcha()
+
+    @strawberry.mutation(description=__doc__)
+    @sync_to_async
+    def afield(self) -> CaptchaType:
+        return CaptchaModel.create_captcha()
 
 
 class RegisterMixin:
@@ -98,8 +111,8 @@ class RegisterMixin:
     def check_captcha(cls, input_):
         uuid = input_.get("identifier")
         try:
-            obj = Captcha.objects.get(uuid=uuid)
-        except Captcha.DoesNotExist:
+            obj = CaptchaModel.objects.get(uuid=uuid)
+        except CaptchaModel.DoesNotExist:
             return Messages.CAPTCHA_EXPIRED
         return obj.validate(input_.get("userEntry"))
 
@@ -124,18 +137,10 @@ class RegisterMixin:
                         and email
                     )
                     if send_activation:
-                        # TODO CHECK FOR EMAIL ASYNC SETTING
-                        if async_email_func:
-                            async_email_func(user.status.send_activation_email, (info,))
-                        else:
-                            user.status.send_activation_email(info)
+                        user.status.send_activation_email(info)
 
                     if send_password_set:
-                        # TODO CHECK FOR EMAIL ASYNC SETTING
-                        if async_email_func:
-                            async_email_func(user.status.send_password_set_email, (info,))
-                        else:
-                            user.status.send_password_set_email(info)
+                        user.status.send_password_set_email(info)
 
                     user_registered.send(sender=cls, user=user)
                     return cls.output(success=True)
@@ -237,10 +242,7 @@ class ResendActivationEmailMixin:
             f = EmailForm({"email": email})
             if f.is_valid():
                 user = get_user_by_email(email)
-                if async_email_func:
-                    async_email_func(user.status.resend_activation_email, (info,))
-                else:
-                    user.status.resend_activation_email(info)
+                user.status.resend_activation_email(info)
                 return cls.output(success=True)
             return cls.output(success=False, errors=f.errors.get_json_data())
         except ObjectDoesNotExist:
@@ -274,10 +276,7 @@ class SendPasswordResetEmailMixin:
             f = EmailForm({"email": email})
             if f.is_valid():
                 user = get_user_by_email(email)
-                if async_email_func:
-                    async_email_func(user.status.send_password_reset_email, (info, [email]))
-                else:
-                    user.status.send_password_reset_email(info, [email])
+                user.status.send_password_reset_email(info, [email])
                 return cls.output(success=True)
             return cls.output(success=False, errors=f.errors.get_json_data())
         except ObjectDoesNotExist:
@@ -287,10 +286,7 @@ class SendPasswordResetEmailMixin:
         except UserNotVerified:
             user = get_user_by_email(email)
             try:
-                if async_email_func:
-                    async_email_func(user.status.resend_activation_email, (info,))
-                else:
-                    user.status.resend_activation_email(info)
+                user.status.resend_activation_email(info)
                 return cls(
                     success=False,
                     errors={"email": Messages.NOT_VERIFIED_PASSWORD_RESET},
@@ -430,8 +426,8 @@ class ObtainJSONWebTokenMixin:
     def check_captcha(cls, **input_):
         uuid = input_.get("identifier")
         try:
-            obj = Captcha.objects.get(uuid=uuid)
-        except Captcha.DoesNotExist:
+            obj = CaptchaModel.objects.get(uuid=uuid)
+        except CaptchaModel.DoesNotExist:
             return Messages.CAPTCHA_EXPIRED
 
         return obj.validate(input_.get("userEntry"))
@@ -453,13 +449,12 @@ class ObtainJSONWebTokenMixin:
             user = get_user_to_login(**query_input_)
             query_input_["password"] = password
 
-            if user.status.archived is True:  # unarchive on login
+            if user.status.archived is True:  # un-archive on login
                 UserStatus.unarchive(user)
 
             if user.status.verified or app_settings.ALLOW_LOGIN_NOT_VERIFIED:
                 # this will raise if not successful
                 res = cls.obtain.get_result(None, None, [cls, info], query_input_)
-
                 return cls.output(success=True, obtainPayload=res)
             else:
                 raise UserNotVerified
@@ -672,10 +667,7 @@ class SendSecondaryEmailActivationMixin:
             f = EmailForm({"email": email})
             if f.is_valid():
                 user = g_user(info)
-                if async_email_func:
-                    async_email_func(user.status.send_secondary_email_activation, (info, email))
-                else:
-                    user.status.send_secondary_email_activation(info, email)
+                user.status.send_secondary_email_activation(info, email)
                 return cls.output(success=True)
             return cls.output(success=False, errors=f.errors.get_json_data())
         except EmailAlreadyInUse:
@@ -701,7 +693,7 @@ class SwapEmailsMixin:
     @secondary_email_required
     @password_confirmation_required
     def resolve_mutation(cls, info, **input_):
-        info.context.user.status.swap_emails()
+        g_user(info).status.swap_emails()
         return cls.output(success=True)
 
 
@@ -718,6 +710,6 @@ class RemoveSecondaryEmailMixin:
     @classmethod
     @secondary_email_required
     @password_confirmation_required
-    def resolve_mutation(cls, info, **input_):
-        info.context.user.status.remove_secondary_email()
+    def resolve_mutation(cls, info: Info, **input_):
+        g_user(info).status.remove_secondary_email()
         return cls.output(success=True)
